@@ -11,6 +11,9 @@ type KeyMap struct {
 	Search         key.Binding
 	Quit           key.Binding
 	Copy           key.Binding
+	TogglePanel    key.Binding
+	OpenInEditor   key.Binding
+	ToggleDiffView key.Binding
 }
 
 var keys = &KeyMap{
@@ -46,10 +49,23 @@ var keys = &KeyMap{
 		key.WithKeys("y"),
 		key.WithHelp("y", "copy file path"),
 	),
+	TogglePanel: key.NewBinding(
+		key.WithKeys("tab"),
+		key.WithHelp("TAB", "switch panel"),
+	),
+	OpenInEditor: key.NewBinding(
+		key.WithKeys("o"),
+		key.WithHelp("o", "open"),
+	),
+	ToggleDiffView: key.NewBinding(
+		key.WithKeys("s"),
+		key.WithHelp("s", "toggle side-by-side"),
+	),
 }
 
 func getKeys() []key.Binding {
 	return []key.Binding{
+		keys.TogglePanel,
 		keys.Up,
 		keys.Down,
 		keys.CtrlD,
@@ -57,6 +73,8 @@ func getKeys() []key.Binding {
 		keys.ToggleFileTree,
 		keys.Search,
 		keys.Copy,
+		keys.OpenInEditor,
+		keys.ToggleDiffView,
 		keys.Quit,
 	}
 }
