@@ -11,6 +11,7 @@ import (
 	"github.com/charmbracelet/bubbles/viewport"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
+	"github.com/charmbracelet/x/ansi"
 
 	"github.com/dlvhdr/diffnav/pkg/ui/common"
 )
@@ -19,14 +20,16 @@ const dirHeaderHeight = 3
 
 type Model struct {
 	common.Common
-	vp     viewport.Model
-	buffer *bytes.Buffer
-	file   *gitdiff.File
+	vp         viewport.Model
+	buffer     *bytes.Buffer
+	file       *gitdiff.File
+	sideBySide bool
 }
 
-func New() Model {
+func New(sideBySide bool) Model {
 	return Model{
-		vp: viewport.Model{},
+		vp:         viewport.Model{},
+		sideBySide: sideBySide,
 	}
 }
 
@@ -50,7 +53,14 @@ func (m Model) Update(msg tea.Msg) (Model, tea.Cmd) {
 		}
 
 	case diffContentMsg:
-		m.vp.SetContent(msg.text)
+		// Truncate lines to viewport width to prevent ANSI escape overflow.
+		lines := strings.Split(msg.text, "\n")
+		for i, line := range lines {
+			if lipgloss.Width(line) > m.vp.Width && m.vp.Width > 0 {
+				lines[i] = ansi.Truncate(line, m.vp.Width, "")
+			}
+		}
+		m.vp.SetContent(strings.Join(lines, "\n"))
 	}
 
 	return m, tea.Batch(cmds...)
@@ -68,7 +78,7 @@ func (m *Model) SetSize(width, height int) tea.Cmd {
 	m.Height = height
 	m.vp.Width = m.Width
 	m.vp.Height = m.Height - dirHeaderHeight
-	return diff(m.file, m.Width)
+	return diff(m.file, m.Width, m.sideBySide)
 }
 
 func (m Model) headerView() string {
@@ -109,21 +119,50 @@ func (m Model) headerView() string {
 func (m Model) SetFilePatch(file *gitdiff.File) (Model, tea.Cmd) {
 	m.buffer = new(bytes.Buffer)
 	m.file = file
-	return m, diff(m.file, m.Width)
+	return m, diff(m.file, m.Width, m.sideBySide)
 }
 
 func (m *Model) GoToTop() {
 	m.vp.GotoTop()
 }
 
-func diff(file *gitdiff.File, width int) tea.Cmd {
+// SetSideBySide updates the diff view mode and re-renders.
+func (m *Model) SetSideBySide(sideBySide bool) tea.Cmd {
+	m.sideBySide = sideBySide
+	return diff(m.file, m.Width, m.sideBySide)
+}
+
+func (m *Model) LineUp(n int) {
+	m.vp.LineUp(n)
+}
+
+func (m *Model) LineDown(n int) {
+	m.vp.LineDown(n)
+}
+
+// ScrollUp scrolls the viewport up by the given number of lines.
+func (m *Model) ScrollUp(lines int) {
+	m.vp.LineUp(lines)
+}
+
+// ScrollDown scrolls the viewport down by the given number of lines.
+func (m *Model) ScrollDown(lines int) {
+	m.vp.LineDown(lines)
+}
+
+func diff(file *gitdiff.File, width int, sideBySidePreference bool) tea.Cmd {
 	if width == 0 || file == nil {
 		return nil
 	}
 	return func() tea.Msg {
-		sideBySide := !file.IsNew && !file.IsDelete
-		args := []string{"--paging=never", fmt.Sprintf("-w=%d", width)}
-		if sideBySide {
+		// Only use side-by-side if preference is true AND file is not new/deleted
+		useSideBySide := sideBySidePreference && !file.IsNew && !file.IsDelete
+		args := []string{
+			"--paging=never",
+			fmt.Sprintf("-w=%d", width),
+			fmt.Sprintf("--max-line-length=%d", width),
+		}
+		if useSideBySide {
 			args = append(args, "--side-by-side")
 		}
 		deltac := exec.Command("delta", args...)
